@@ -1,7 +1,7 @@
 from subprocess import Popen, PIPE
 import shlex
 
-def run_command(command):
+def run_command(command, callback=None):
   process = Popen(shlex.split(command), stdout=PIPE, stderr=PIPE, universal_newlines=True)
   while True:
       output = process.stdout.readline()
@@ -10,6 +10,11 @@ def run_command(command):
       if output:
           print(output.strip())
   rc = process.poll()
+
+  if callback:
+    error_output = process.stderr.readlines()
+    callback(error_output)
+
   return rc
 
 def run_with_pipe(command):
