@@ -19,7 +19,13 @@ def init_git(repositoryUrl,
     )
 
     # Checkout the branch
-    _run_command("git checkout {}".format(branch))
+    os.system('cd "$(basename {} .git)" && git checkout {}'.format(repositoryUrl,branch))
+    
+    # Make sure that even if the repository is public, the personal token is still in the origin remote url
+    if personal_token:
+      os.system("git remote set-url origin {}".format(
+        repositoryUrl.replace("github.com", personal_token+"@github.com")
+      ))
 
     # Add the email and username
     if email: os.system('git config --global user.email "{}"'.format(email))
@@ -28,7 +34,9 @@ def init_git(repositoryUrl,
 
     os.system("mkdir -p ~/.ssh && curl -L -f {} {}/{}/.colab_ssh/authorized_keys >> ~/.ssh/authorized_keys".format(
         ("-H 'Authorization: token {}'".format(personal_token)) if personal_token else "",
-        repositoryUrl.rstrip(".git").replace("github.com", "raw.githubusercontent.com"), 
+        repositoryUrl.split(".git")[0].replace("github.com", "raw.githubusercontent.com"), 
         branch))
 
-    print("Successfully cloned the repository")
\ No newline at end of file
+    print("Successfully cloned the repository")
+
+    
